searchData={"items":[{"type":"module","title":"Typst","doc":"This module provides the core functions for interacting with\nthe `typst` markup language compiler.\n\nNote that when using the formatting directives, they are exactly the same as\n`EEx`, so all of its constructs are supported.\n\nSee [Typst's documentation](https://typst.app/docs) for a quickstart.","ref":"Typst.html"},{"type":"type","title":"Typst.formattable/0","doc":"","ref":"Typst.html#t:formattable/0"},{"type":"type","title":"Typst.pdf_opt/0","doc":"","ref":"Typst.html#t:pdf_opt/0"},{"type":"function","title":"Typst.render_to_pdf/3","doc":"Converts a given piece of typst markup to a PDF binary.","ref":"Typst.html#render_to_pdf/3"},{"type":"function","title":"Examples - Typst.render_to_pdf/3","doc":"iex> {:ok, pdf} = Typst.render_to_pdf(\"= test\\n<%= name %>\", name: \"John\")\n    iex> is_binary(pdf)\n    true","ref":"Typst.html#render_to_pdf/3-examples"},{"type":"function","title":"Typst.render_to_pdf!/2","doc":"Same as `render_to_pdf/2`, but raises if the rendering fails.","ref":"Typst.html#render_to_pdf!/2"},{"type":"function","title":"Typst.render_to_string/2","doc":"Formats the given markup template with the given bindings, mostly \nuseful for inspecting and debugging.","ref":"Typst.html#render_to_string/2"},{"type":"function","title":"Examples - Typst.render_to_string/2","doc":"iex> Typst.render_to_string(\"= Hey <%= name %>!\", name: \"Jude\")\n    \"= Hey Jude!\"","ref":"Typst.html#render_to_string/2-examples"},{"type":"module","title":"Typst.Format","doc":"Contains helper functions for converting elixir datatypes into \nthe format that Typst expects","ref":"Typst.Format.html"},{"type":"function","title":"Typst.Format.array/1","doc":"","ref":"Typst.Format.html#array/1"},{"type":"function","title":"Typst.Format.bold/1","doc":"","ref":"Typst.Format.html#bold/1"},{"type":"type","title":"Typst.Format.column_data/0","doc":"","ref":"Typst.Format.html#t:column_data/0"},{"type":"function","title":"Typst.Format.content/1","doc":"","ref":"Typst.Format.html#content/1"},{"type":"function","title":"Typst.Format.table_content/1","doc":"Converts a series of columns mapped as a nested list to a format that can be \nplugged in an existing table.","ref":"Typst.Format.html#table_content/1"},{"type":"function","title":"Examples - Typst.Format.table_content/1","doc":"iex> columns = [[\"John\", 10, 20], [\"Alice\", 20, 30]]\n    iex> Typst.Format.table_content(columns)\n    ~s/\"John\", \"10\", \"20\",\\n  \"Alice\", \"20\", \"30\"/","ref":"Typst.Format.html#table_content/1-examples"},{"type":"module","title":"Typst.Format.Table","doc":"Creates a typst [`#table()`](https://typst.app/docs/reference/model/table) and implements the `String.Chars` protocol for easy EEx interpolation.\nTo build more complex tables you can use the structs under this module like `Typst.Format.Table.Hline`","ref":"Typst.Format.Table.html"},{"type":"module","title":"Examples - Typst.Format.Table","doc":"iex> alias Typst.Format.Table\n    ...> %Table{columns: 2, content: [[\"hello\", \"world\"], [\"foo\", \"bar\"]]} |> to_string()\n    \"#table(columns: 2, [hello], [world], [foo], [bar])\"\n\n    iex> alias Typst.Format.Table\n    ...> alias Typst.Format.Table.Hline\n    ...> import Typst.Format\n    ...> %Table{columns: array([\"1fr\", \"1fr\"]), content: [[\"hello\", \"world\"], %Hline{start: 1}, [\"foo\", \"bar\"]]} |> to_string()\n    \"#table(columns: (1fr, 1fr), [hello], [world], table.hline(start: 1), [foo], [bar])\"","ref":"Typst.Format.Table.html#module-examples"},{"type":"type","title":"Typst.Format.Table.t/0","doc":"","ref":"Typst.Format.Table.html#t:t/0"},{"type":"module","title":"Typst.Format.Table.Cell","doc":"Creates a typst [`table.cell()`](https://typst.app/docs/reference/model/table/#definitions-cell) and implements the `String.Chars` protocol for easy EEx interpolation.","ref":"Typst.Format.Table.Cell.html"},{"type":"module","title":"Examples - Typst.Format.Table.Cell","doc":"iex> alias Typst.Format.Table.Cell\n    ...> %Cell{x: 2, content: [\"hello\", \"world\"]} |> to_string()\n    \"table.cell(x: 2, [hello], [world])\"","ref":"Typst.Format.Table.Cell.html#module-examples"},{"type":"type","title":"Typst.Format.Table.Cell.t/0","doc":"","ref":"Typst.Format.Table.Cell.html#t:t/0"},{"type":"module","title":"Typst.Format.Table.Footer","doc":"Creates a typst [`table.footer()`](https://typst.app/docs/reference/model/table/#definitions-footer) and implements the `String.Chars` protocol for easy EEx interpolation.","ref":"Typst.Format.Table.Footer.html"},{"type":"module","title":"Examples - Typst.Format.Table.Footer","doc":"iex> alias Typst.Format.Table.Footer\n    ...> %Footer{repeat: false, content: [\"hello\", \"world\"]} |> to_string()\n    \"table.footer(repeat: false, [hello], [world])\"","ref":"Typst.Format.Table.Footer.html#module-examples"},{"type":"type","title":"Typst.Format.Table.Footer.t/0","doc":"","ref":"Typst.Format.Table.Footer.html#t:t/0"},{"type":"module","title":"Typst.Format.Table.Header","doc":"Creates a typst [`table.header()`](https://typst.app/docs/reference/model/table/#definitions-header) and implements the `String.Chars` protocol for easy EEx interpolation.","ref":"Typst.Format.Table.Header.html"},{"type":"module","title":"Examples - Typst.Format.Table.Header","doc":"iex> alias Typst.Format.Table.Header\n    ...> %Header{repeat: false, content: [\"hello\", \"world\"]} |> to_string()\n    \"table.header(repeat: false, [hello], [world])\"","ref":"Typst.Format.Table.Header.html#module-examples"},{"type":"type","title":"Typst.Format.Table.Header.t/0","doc":"","ref":"Typst.Format.Table.Header.html#t:t/0"},{"type":"module","title":"Typst.Format.Table.Hline","doc":"Creates a typst [`table.hline()`](https://typst.app/docs/reference/model/table/#definitions-hline) and implements the `String.Chars` protocol for easy EEx interpolation.","ref":"Typst.Format.Table.Hline.html"},{"type":"module","title":"Examples - Typst.Format.Table.Hline","doc":"iex> alias Typst.Format.Table.Hline\n    ...> %Hline{start: 2} |> to_string()\n    \"table.hline(start: 2)\"","ref":"Typst.Format.Table.Hline.html#module-examples"},{"type":"type","title":"Typst.Format.Table.Hline.t/0","doc":"","ref":"Typst.Format.Table.Hline.html#t:t/0"},{"type":"module","title":"Typst.Format.Table.Vline","doc":"Creates a typst [`table.vline()`](https://typst.app/docs/reference/model/table/#definitions-vline) and implements the `String.Chars` protocol for easy EEx interpolation.","ref":"Typst.Format.Table.Vline.html"},{"type":"module","title":"Examples - Typst.Format.Table.Vline","doc":"iex> alias Typst.Format.Table.Vline\n    ...> %Vline{start: 2} |> to_string()\n    \"table.vline(start: 2)\"","ref":"Typst.Format.Table.Vline.html#module-examples"},{"type":"type","title":"Typst.Format.Table.Vline.t/0","doc":"","ref":"Typst.Format.Table.Vline.html#t:t/0"},{"type":"extras","title":"Typst","doc":"# Typst\n\nThis library interfaces with the Typst typesetting rust library","ref":"readme.html"},{"type":"extras","title":"Installation - Typst","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `typst` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:typst, \"~> 0.1\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}